/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM flockILucene.idl
 */

#ifndef __gen_flockILucene_h__
#define __gen_flockILucene_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIFile; /* forward declaration */

class nsISimpleEnumerator; /* forward declaration */


/* starting interface:    flockILuceneResult */
#define FLOCKILUCENERESULT_IID_STR "625248a0-9d3f-4060-9585-a765b8242df3"

#define FLOCKILUCENERESULT_IID \
  {0x625248a0, 0x9d3f, 0x4060, \
    { 0x95, 0x85, 0xa7, 0x65, 0xb8, 0x24, 0x2d, 0xf3 }}

/**
 * flockILuceneResult
 *
 * This is an interface that describes a result from a Lucene query.
 */
class NS_NO_VTABLE NS_SCRIPTABLE flockILuceneResult : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(FLOCKILUCENERESULT_IID)

  /* readonly attribute string URI; */
  NS_SCRIPTABLE NS_IMETHOD GetURI(char * *aURI) = 0;

  /* readonly attribute string type; */
  NS_SCRIPTABLE NS_IMETHOD GetType(char * *aType) = 0;

  /* readonly attribute wstring URL; */
  NS_SCRIPTABLE NS_IMETHOD GetURL(PRUnichar * *aURL) = 0;

  /* readonly attribute wstring title; */
  NS_SCRIPTABLE NS_IMETHOD GetTitle(PRUnichar * *aTitle) = 0;

  /* readonly attribute double score; */
  NS_SCRIPTABLE NS_IMETHOD GetScore(double *aScore) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(flockILuceneResult, FLOCKILUCENERESULT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKILUCENERESULT \
  NS_SCRIPTABLE NS_IMETHOD GetURI(char * *aURI); \
  NS_SCRIPTABLE NS_IMETHOD GetType(char * *aType); \
  NS_SCRIPTABLE NS_IMETHOD GetURL(PRUnichar * *aURL); \
  NS_SCRIPTABLE NS_IMETHOD GetTitle(PRUnichar * *aTitle); \
  NS_SCRIPTABLE NS_IMETHOD GetScore(double *aScore); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKILUCENERESULT(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetURI(char * *aURI) { return _to GetURI(aURI); } \
  NS_SCRIPTABLE NS_IMETHOD GetType(char * *aType) { return _to GetType(aType); } \
  NS_SCRIPTABLE NS_IMETHOD GetURL(PRUnichar * *aURL) { return _to GetURL(aURL); } \
  NS_SCRIPTABLE NS_IMETHOD GetTitle(PRUnichar * *aTitle) { return _to GetTitle(aTitle); } \
  NS_SCRIPTABLE NS_IMETHOD GetScore(double *aScore) { return _to GetScore(aScore); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKILUCENERESULT(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetURI(char * *aURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetURI(aURI); } \
  NS_SCRIPTABLE NS_IMETHOD GetType(char * *aType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetType(aType); } \
  NS_SCRIPTABLE NS_IMETHOD GetURL(PRUnichar * *aURL) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetURL(aURL); } \
  NS_SCRIPTABLE NS_IMETHOD GetTitle(PRUnichar * *aTitle) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetTitle(aTitle); } \
  NS_SCRIPTABLE NS_IMETHOD GetScore(double *aScore) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetScore(aScore); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockILuceneResult
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKILUCENERESULT

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockILuceneResult)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* readonly attribute string URI; */
NS_IMETHODIMP _MYCLASS_::GetURI(char * *aURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute string type; */
NS_IMETHODIMP _MYCLASS_::GetType(char * *aType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute wstring URL; */
NS_IMETHODIMP _MYCLASS_::GetURL(PRUnichar * *aURL)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute wstring title; */
NS_IMETHODIMP _MYCLASS_::GetTitle(PRUnichar * *aTitle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute double score; */
NS_IMETHODIMP _MYCLASS_::GetScore(double *aScore)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    flockILuceneSearchCallback */
#define FLOCKILUCENESEARCHCALLBACK_IID_STR "288ac5a5-4671-4ddf-8dff-e3a98a5385ba"

#define FLOCKILUCENESEARCHCALLBACK_IID \
  {0x288ac5a5, 0x4671, 0x4ddf, \
    { 0x8d, 0xff, 0xe3, 0xa9, 0x8a, 0x53, 0x85, 0xba }}

/**
 * flockILuceneSearchCallback
 * 
 * This is a callback interface that gets called when a search query completes.
 */
class NS_NO_VTABLE NS_SCRIPTABLE flockILuceneSearchCallback : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(FLOCKILUCENESEARCHCALLBACK_IID)

  /**
   * Called on completion of an associated flockILucene search call.
   *
   * @param aNumResults
   *        the number of search results being returned
   * @param aResultsEnumerator
   *        an enumerator of flockILuceneResults
   */
  /* void handleResults (in unsigned long aNumResults, in nsISimpleEnumerator aResultsEnumerator); */
  NS_SCRIPTABLE NS_IMETHOD HandleResults(PRUint32 aNumResults, nsISimpleEnumerator *aResultsEnumerator) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(flockILuceneSearchCallback, FLOCKILUCENESEARCHCALLBACK_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKILUCENESEARCHCALLBACK \
  NS_SCRIPTABLE NS_IMETHOD HandleResults(PRUint32 aNumResults, nsISimpleEnumerator *aResultsEnumerator); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKILUCENESEARCHCALLBACK(_to) \
  NS_SCRIPTABLE NS_IMETHOD HandleResults(PRUint32 aNumResults, nsISimpleEnumerator *aResultsEnumerator) { return _to HandleResults(aNumResults, aResultsEnumerator); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKILUCENESEARCHCALLBACK(_to) \
  NS_SCRIPTABLE NS_IMETHOD HandleResults(PRUint32 aNumResults, nsISimpleEnumerator *aResultsEnumerator) { return !_to ? NS_ERROR_NULL_POINTER : _to->HandleResults(aNumResults, aResultsEnumerator); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockILuceneSearchCallback
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKILUCENESEARCHCALLBACK

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockILuceneSearchCallback)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void handleResults (in unsigned long aNumResults, in nsISimpleEnumerator aResultsEnumerator); */
NS_IMETHODIMP _MYCLASS_::HandleResults(PRUint32 aNumResults, nsISimpleEnumerator *aResultsEnumerator)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    flockILuceneIndexListener */
#define FLOCKILUCENEINDEXLISTENER_IID_STR "69694cf8-ff73-4c00-9fe5-aefc6f458704"

#define FLOCKILUCENEINDEXLISTENER_IID \
  {0x69694cf8, 0xff73, 0x4c00, \
    { 0x9f, 0xe5, 0xae, 0xfc, 0x6f, 0x45, 0x87, 0x04 }}

/**
 * flockILuceneIndexListener
 * 
 * This is a listener interface that is called when an asynchronous index
 * modification operation completes.
 */
class NS_NO_VTABLE NS_SCRIPTABLE flockILuceneIndexListener : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(FLOCKILUCENEINDEXLISTENER_IID)

  /**
   * Called on completion of an associated flockILucene addDocument call.
   *
   * @param aURI
   *        the URI of the document that has been added
   */
  /* void onAddDocumentComplete (in string aURI); */
  NS_SCRIPTABLE NS_IMETHOD OnAddDocumentComplete(const char *aURI) = 0;

  /**
   * Called on completion of an associated flockILucene deleteDocument call.
   *
   * @param aURI
   *        the URI of the document that has been deleted
   */
  /* void onDeleteDocumentComplete (in string aURI); */
  NS_SCRIPTABLE NS_IMETHOD OnDeleteDocumentComplete(const char *aURI) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(flockILuceneIndexListener, FLOCKILUCENEINDEXLISTENER_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKILUCENEINDEXLISTENER \
  NS_SCRIPTABLE NS_IMETHOD OnAddDocumentComplete(const char *aURI); \
  NS_SCRIPTABLE NS_IMETHOD OnDeleteDocumentComplete(const char *aURI); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKILUCENEINDEXLISTENER(_to) \
  NS_SCRIPTABLE NS_IMETHOD OnAddDocumentComplete(const char *aURI) { return _to OnAddDocumentComplete(aURI); } \
  NS_SCRIPTABLE NS_IMETHOD OnDeleteDocumentComplete(const char *aURI) { return _to OnDeleteDocumentComplete(aURI); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKILUCENEINDEXLISTENER(_to) \
  NS_SCRIPTABLE NS_IMETHOD OnAddDocumentComplete(const char *aURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnAddDocumentComplete(aURI); } \
  NS_SCRIPTABLE NS_IMETHOD OnDeleteDocumentComplete(const char *aURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnDeleteDocumentComplete(aURI); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockILuceneIndexListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKILUCENEINDEXLISTENER

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockILuceneIndexListener)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void onAddDocumentComplete (in string aURI); */
NS_IMETHODIMP _MYCLASS_::OnAddDocumentComplete(const char *aURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void onDeleteDocumentComplete (in string aURI); */
NS_IMETHODIMP _MYCLASS_::OnDeleteDocumentComplete(const char *aURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    flockILucene */
#define FLOCKILUCENE_IID_STR "5d8477b5-3ce0-4bbd-a7f2-6405aeee436e"

#define FLOCKILUCENE_IID \
  {0x5d8477b5, 0x3ce0, 0x4bbd, \
    { 0xa7, 0xf2, 0x64, 0x05, 0xae, 0xee, 0x43, 0x6e }}

/**
 * flockILucene
 * 
 * This interface maintains and provides access to a Lucene indexer thread.
 */
class NS_NO_VTABLE NS_SCRIPTABLE flockILucene : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(FLOCKILUCENE_IID)

  /**
   * Initialize the Lucene thread using the directory aIndexDir
   *
   * @param aIndexDir
   *        a Lucene index directory containing Lucene index files
   */
  /* void init (in nsIFile aIndexDir); */
  NS_SCRIPTABLE NS_IMETHOD Init(nsIFile *aIndexDir) = 0;

  /**
   * Adds a document to the Lucene index.  The request to do this will
   * be dispatched to the worker thread for the actual indexing.
   *
   * @param aURI
   *        the URI of the document to be indexed
   * @param aType
   *        the Flock Type of the document
   * @param aURL
   *        the URL of the document, if one exists
   * @param aTitle
   *        the title of the document
   * @param aTags
   *        comma delimited string of tags for the document, if any exist
   * @param aDescription
   *        notes or other out-of-band text attached to the document
   * @param aText
   *        the text of the document
   * @param aLuceneListener
   *        a listener to be called when the document has been added
   */
  /* void addDocument (in string aURI, in string aType, in AString aURL, in AString aTitle, in AString aTags, in AString aDescription, in AString aText, in flockILuceneIndexListener aLuceneIndexListener); */
  NS_SCRIPTABLE NS_IMETHOD AddDocument(const char *aURI, const char *aType, const nsAString & aURL, const nsAString & aTitle, const nsAString & aTags, const nsAString & aDescription, const nsAString & aText, flockILuceneIndexListener *aLuceneIndexListener) = 0;

  /**
   * Adds a document to the Lucene index synchronously.  The request to
   * do this will be dispatched to the worker thread for the actual
   * indexing.
   *
   * @param aURI
   *        the URI of the document to be indexed
   * @param aType
   *        the Flock Type of the document
   * @param aURL
   *        the URL of the document, if one exists
   * @param aTitle
   *        the title of the document
   * @param aTags
   *        comma delimited string of tags for the document, if any exist
   * @param aDescription
   *        notes or other out-of-band text attached to the document
   * @param aText
   *        the text of the document
   */
  /* void addDocumentSync (in string aURI, in string aType, in AString aURL, in AString aTitle, in AString aTags, in AString aDescription, in AString aText); */
  NS_SCRIPTABLE NS_IMETHOD AddDocumentSync(const char *aURI, const char *aType, const nsAString & aURL, const nsAString & aTitle, const nsAString & aTags, const nsAString & aDescription, const nsAString & aText) = 0;

  /**
   * Removes a document from the Lucene index.
   *
   * @param aURI
   *        the URI of the document to be removed
   * @param aLuceneListener
   *        a listener to be called when the document has been deleted
   */
  /* void deleteDocument (in string aURI, in flockILuceneIndexListener aLuceneIndexListener); */
  NS_SCRIPTABLE NS_IMETHOD DeleteDocument(const char *aURI, flockILuceneIndexListener *aLuceneIndexListener) = 0;

  /**
   * Removes a document from the Lucene index synchronously.
   *
   * @param aURI
   *        the URI of the document to be removed
   */
  /* void deleteDocumentSync (in string aURI); */
  NS_SCRIPTABLE NS_IMETHOD DeleteDocumentSync(const char *aURI) = 0;

  /**
   * Searches the Lucene index.
   *
   * @param aQuery
   *        a Lucene query string
   * @param aType
   *        a Flock Type to restrict the search to.  NULL searches all types.
   * @param aMaxResults
   *        the maximum number of results to return
   * @param aLuceneSearchCallback
   *        flockILuceneSearchCallback interface to be called when the search
   *        is complete
   */
  /* void search (in AString aQuery, in string aType, in long aMaxResults, in flockILuceneSearchCallback aLuceneSearchCallback); */
  NS_SCRIPTABLE NS_IMETHOD Search(const nsAString & aQuery, const char *aType, PRInt32 aMaxResults, flockILuceneSearchCallback *aLuceneSearchCallback) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(flockILucene, FLOCKILUCENE_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_FLOCKILUCENE \
  NS_SCRIPTABLE NS_IMETHOD Init(nsIFile *aIndexDir); \
  NS_SCRIPTABLE NS_IMETHOD AddDocument(const char *aURI, const char *aType, const nsAString & aURL, const nsAString & aTitle, const nsAString & aTags, const nsAString & aDescription, const nsAString & aText, flockILuceneIndexListener *aLuceneIndexListener); \
  NS_SCRIPTABLE NS_IMETHOD AddDocumentSync(const char *aURI, const char *aType, const nsAString & aURL, const nsAString & aTitle, const nsAString & aTags, const nsAString & aDescription, const nsAString & aText); \
  NS_SCRIPTABLE NS_IMETHOD DeleteDocument(const char *aURI, flockILuceneIndexListener *aLuceneIndexListener); \
  NS_SCRIPTABLE NS_IMETHOD DeleteDocumentSync(const char *aURI); \
  NS_SCRIPTABLE NS_IMETHOD Search(const nsAString & aQuery, const char *aType, PRInt32 aMaxResults, flockILuceneSearchCallback *aLuceneSearchCallback); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_FLOCKILUCENE(_to) \
  NS_SCRIPTABLE NS_IMETHOD Init(nsIFile *aIndexDir) { return _to Init(aIndexDir); } \
  NS_SCRIPTABLE NS_IMETHOD AddDocument(const char *aURI, const char *aType, const nsAString & aURL, const nsAString & aTitle, const nsAString & aTags, const nsAString & aDescription, const nsAString & aText, flockILuceneIndexListener *aLuceneIndexListener) { return _to AddDocument(aURI, aType, aURL, aTitle, aTags, aDescription, aText, aLuceneIndexListener); } \
  NS_SCRIPTABLE NS_IMETHOD AddDocumentSync(const char *aURI, const char *aType, const nsAString & aURL, const nsAString & aTitle, const nsAString & aTags, const nsAString & aDescription, const nsAString & aText) { return _to AddDocumentSync(aURI, aType, aURL, aTitle, aTags, aDescription, aText); } \
  NS_SCRIPTABLE NS_IMETHOD DeleteDocument(const char *aURI, flockILuceneIndexListener *aLuceneIndexListener) { return _to DeleteDocument(aURI, aLuceneIndexListener); } \
  NS_SCRIPTABLE NS_IMETHOD DeleteDocumentSync(const char *aURI) { return _to DeleteDocumentSync(aURI); } \
  NS_SCRIPTABLE NS_IMETHOD Search(const nsAString & aQuery, const char *aType, PRInt32 aMaxResults, flockILuceneSearchCallback *aLuceneSearchCallback) { return _to Search(aQuery, aType, aMaxResults, aLuceneSearchCallback); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_FLOCKILUCENE(_to) \
  NS_SCRIPTABLE NS_IMETHOD Init(nsIFile *aIndexDir) { return !_to ? NS_ERROR_NULL_POINTER : _to->Init(aIndexDir); } \
  NS_SCRIPTABLE NS_IMETHOD AddDocument(const char *aURI, const char *aType, const nsAString & aURL, const nsAString & aTitle, const nsAString & aTags, const nsAString & aDescription, const nsAString & aText, flockILuceneIndexListener *aLuceneIndexListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddDocument(aURI, aType, aURL, aTitle, aTags, aDescription, aText, aLuceneIndexListener); } \
  NS_SCRIPTABLE NS_IMETHOD AddDocumentSync(const char *aURI, const char *aType, const nsAString & aURL, const nsAString & aTitle, const nsAString & aTags, const nsAString & aDescription, const nsAString & aText) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddDocumentSync(aURI, aType, aURL, aTitle, aTags, aDescription, aText); } \
  NS_SCRIPTABLE NS_IMETHOD DeleteDocument(const char *aURI, flockILuceneIndexListener *aLuceneIndexListener) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteDocument(aURI, aLuceneIndexListener); } \
  NS_SCRIPTABLE NS_IMETHOD DeleteDocumentSync(const char *aURI) { return !_to ? NS_ERROR_NULL_POINTER : _to->DeleteDocumentSync(aURI); } \
  NS_SCRIPTABLE NS_IMETHOD Search(const nsAString & aQuery, const char *aType, PRInt32 aMaxResults, flockILuceneSearchCallback *aLuceneSearchCallback) { return !_to ? NS_ERROR_NULL_POINTER : _to->Search(aQuery, aType, aMaxResults, aLuceneSearchCallback); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public flockILucene
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_FLOCKILUCENE

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, flockILucene)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void init (in nsIFile aIndexDir); */
NS_IMETHODIMP _MYCLASS_::Init(nsIFile *aIndexDir)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addDocument (in string aURI, in string aType, in AString aURL, in AString aTitle, in AString aTags, in AString aDescription, in AString aText, in flockILuceneIndexListener aLuceneIndexListener); */
NS_IMETHODIMP _MYCLASS_::AddDocument(const char *aURI, const char *aType, const nsAString & aURL, const nsAString & aTitle, const nsAString & aTags, const nsAString & aDescription, const nsAString & aText, flockILuceneIndexListener *aLuceneIndexListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addDocumentSync (in string aURI, in string aType, in AString aURL, in AString aTitle, in AString aTags, in AString aDescription, in AString aText); */
NS_IMETHODIMP _MYCLASS_::AddDocumentSync(const char *aURI, const char *aType, const nsAString & aURL, const nsAString & aTitle, const nsAString & aTags, const nsAString & aDescription, const nsAString & aText)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteDocument (in string aURI, in flockILuceneIndexListener aLuceneIndexListener); */
NS_IMETHODIMP _MYCLASS_::DeleteDocument(const char *aURI, flockILuceneIndexListener *aLuceneIndexListener)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void deleteDocumentSync (in string aURI); */
NS_IMETHODIMP _MYCLASS_::DeleteDocumentSync(const char *aURI)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void search (in AString aQuery, in string aType, in long aMaxResults, in flockILuceneSearchCallback aLuceneSearchCallback); */
NS_IMETHODIMP _MYCLASS_::Search(const nsAString & aQuery, const char *aType, PRInt32 aMaxResults, flockILuceneSearchCallback *aLuceneSearchCallback)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

// b8e91518-135b-4128-8b79-ca489924f102
#define FLOCK_LUCENE_CID \
{ 0xb8e91518, 0x135b, 0x4128, { 0x8b, 0x79, 0xca, 0x48, 0x99, 0x24, 0xf1, 0x02 } }
#define FLOCK_LUCENE_CLASSNAME "Flock Lucene Search Engine"
#define FLOCK_LUCENE_CONTRACTID "@flock.com/lucene;1"

#endif /* __gen_flockILucene_h__ */
